diff --git src/wp-includes/functions.php src/wp-includes/functions.php
index 0e720ee..9634ed4 100644
--- src/wp-includes/functions.php
+++ src/wp-includes/functions.php
@@ -3031,12 +3031,14 @@ function _wp_json_prepare_data( $data ) {
  * Send a JSON response back to an Ajax request.
  *
  * @since 3.5.0
+ * @since 4.6.0 The `$status_code` parameter was added
  *
  * @param mixed $response Variable (usually an array or object) to encode as JSON,
  *                        then print and die.
  */
-function wp_send_json( $response ) {
+function wp_send_json( $response, $status_code = 200 ) {
 	@header( 'Content-Type: application/json; charset=' . get_option( 'blog_charset' ) );
+	status_header( (int) $status_code );
 	echo wp_json_encode( $response );
 	if ( defined( 'DOING_AJAX' ) && DOING_AJAX )
 		wp_die();
@@ -3048,16 +3050,17 @@ function wp_send_json( $response ) {
  * Send a JSON response back to an Ajax request, indicating success.
  *
  * @since 3.5.0
+ * @since 4.6.0 The `$status_code` parameter was added
  *
  * @param mixed $data Data to encode as JSON, then print and die.
  */
-function wp_send_json_success( $data = null ) {
+function wp_send_json_success( $data = null, $status_code = 200 ) {
 	$response = array( 'success' => true );
 
 	if ( isset( $data ) )
 		$response['data'] = $data;
 
-	wp_send_json( $response );
+	wp_send_json( $response, $status_code );
 }
 
 /**
@@ -3071,10 +3074,12 @@ function wp_send_json_success( $data = null ) {
  * @since 3.5.0
  * @since 4.1.0 The `$data` parameter is now processed if a {@see WP_Error}
  *              object is passed in.
+ * @since 4.6.0 The `$status_code` parameter was added
  *
  * @param mixed $data Data to encode as JSON, then print and die.
  */
-function wp_send_json_error( $data = null ) {
+function wp_send_json_error( $data = null, $status_code = 200 ) {
 	$response = array( 'success' => false );
 
 	if ( isset( $data ) ) {
@@ -3092,7 +3097,7 @@ function wp_send_json_error( $data = null ) {
 		}
 	}
 
-	wp_send_json( $response );
+	wp_send_json( $response, $status_code );
 }
 
 /**
@@ -3071,10 +3074,12 @@ function wp_send_json_success( $data = null ) {
  *
- * @param mixed $data Data to encode as JSON, then print and die.
+ * @param mixed $data        Data to encode as JSON, then print and die.
+ * @param int   $status_code HTTP status code.
  */
